==> RcmdrPlugin.DoE_0.5-3.tar.gz: RcmdrPlugin.DoE/R/menushelp.R <==
## Menu info functions
help2level <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.2level"))
}

helpgeneral <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.General"))
}

helpquant <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.Quantitative"))
}


helpAnalyze <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.Analyze"))
}     
helpGeneralAnalyze <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.GeneralAnalyze"))
}
helpQuantDesignAnalyze <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.QuantDesignAnalyze"))
} 

helpExpImp <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.ExpImp"))
}
helpModify <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.Modify"))
}

displayGlossary <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("DoEGlossary"))
}

displayblock <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("block"))
}

displaysplitplot <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("splitplot"))
}
displayCentralCompositeDesigns <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("CentralCompositeDesigns"))
}

helpMenus <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menus"))
}

HowToReImport <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("HowToReImport"))
}

==> RcmdrPlugin.DoE_0.6-10.tar.gz: RcmdrPlugin.DoE/R/menushelp.R <==
## Menu info functions
helpabout <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("RcmdrPlugin.DoE-package"))
}

onHelpTabEstimable <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.FrF2levelTabEstimable"))
}


help2level <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.2level"))
}

helpgeneral <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.General"))
}

helpquant <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.Quantitative"))
}


helpAnalyze <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.Analyze"))
}     
helpGeneralAnalyze <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.GeneralAnalyze"))
}
helpQuantDesignAnalyze <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.QuantDesignAnalyze"))
} 

helpExpImp <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.ExpImp"))
}
helpModify <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menu.Modify"))
}

displayGlossary <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("DoEGlossary"))
}

displayblock <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("block"))
}

displaysplitplot <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("splitplot"))
}
displayCentralCompositeDesigns <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("CentralCompositeDesigns"))
}

helpMenus <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("Menus"))
}

HowToReImport <- function(){
     if (GrabFocus() && .Platform$OS.type != "windows")
            tkgrab.release(topdes2)
     print(help("HowToReImport"))
}
